#!/bin/bash

# Some formatting
RED="\033[0;31m"
NC="\033[0m" # No Color

RUNDIR=$(pwd)
PARAM_FILE=${RUNDIR}/param.cfg

# Source parameter with config paths
if [[ ! -f ${PARAM_FILE} ]]
then
  ${PARAM_FILE}
else 
  echo "Sourcing param files"
  source ${PARAM_FILE}
fi

# Folder which contains files for remote compiling
REMOTE=${RUNDIR//Local}/Remote

# Folder to store local outputs for remote compiling
NAMELIST_FLD=${REMOTE}/Namelist
DATABASE_FLD=${REMOTE}/Database
PROCESSED_OUTPUTS=${REMOTE}/ProcessedOutputs

# Remove eventual leftovers of old runs
rm -rf   ${DATABASE_FLD} ${NAMELIST_FLD} ${PROCESSED_OUTPUTS} # AutoRPE 
mkdir -p ${DATABASE_FLD} ${NAMELIST_FLD} ${PROCESSED_OUTPUTS}

#download last AutoRPE version
#git clone http://earth.bsc.es/gitlab/otinto/AutoRPE.git --branch dwarf-lonlev-0.91_0


#Check folder on HPC in which the remote implementation will run
ssh ${HPC_USER}@${HPC_MACHINE} '[ -d '${REMOTE_DIR}' ] && echo "Check remote ... ok" || echo  "Remote dir " '${REMOTE_DIR}' "does not exists" '

# Check if given path exists
if [[ ! -d ${DWARF_HOME} ]]
then
  echo -e "The specified folder does not exist: "${DWARF_HOME}"\n${RED}Abort${NC}"
  exit 1 
else
  DWARF_SRC=${DWARF_HOME}/src
  DWARF_NAMELIST=${DWARF_HOME}/escape-acraneb2-input-output/nam_radia_dwarf.nam
fi

AUTORP_HOME=${RUNDIR}/AutoRPE
# Paths hardcoded in Implement_sources
AUTO_RP_IN=${AUTORP_HOME}/ModelSources/Input/
AUTO_RP_OUT=${AUTORP_HOME}/ModelSources/Output/

# Paths harcoded in NamelistPrecisionsGenerator script
OLD_NAMELIST=${AUTORP_HOME}/ParameterNamelists/Original/
NEW_NAMELIST=${AUTORP_HOME}/ParameterNamelists/Modified/

# Precompile and copy F90 files
for file in ${DWARF_SRC}/*.F90
do
 dest_file=${file//${DWARF_SRC}}
 cpp -P -fopenmp  ${file} > ${AUTO_RP_IN}/${dest_file//F90}f90
done

# Copy .f90 files
cp ${DWARF_SRC}/*.f90 ${AUTO_RP_IN}

# Remove legacy files
rm ${AUTO_RP_IN}/*_legacy*

# Ignore opmpi files and timings, which contains no calculation at all
echo -e  \
 'dmi_omp.F90' \
 '\nini_modules.f90' \
 '\ninput_acraneb2.f90' \
 '\noutput_basic.f90' \
 '\ndmi_omp.f90' \
 '\ndmi_timer.f90' > ${AUTORP_HOME}/AdditionalFiles/list_of_files_to_keep_unmodified.txt


# Check python is loaded
python3 -V  >/dev/null 2>&1  ||  { echo "load python3 and try again ..."; exit 1 ; }

cd ${AUTORP_HOME}

# Run the implementation
python3 ImplementRPEtoSource.py 2> implementation.log

# Add call to read variables precisions to mail file 
sed -i "s/ call domp_init(nthreads)/ call domp_init(nthreads)\n CALL read_variable_precisions/g" ${AUTO_RP_OUT}/main.f90 

#Copy procecced files
cp ${AUTO_RP_OUT}/* ${PROCESSED_OUTPUTS}
cp -r ${DWARF_HOME} ${RUNDIR}/../Remote

# Copy namelist original namelist
cp ${DWARF_NAMELIST} ${OLD_NAMELIST}

# Generate namelist_precisions
python3 NamelistPrecisionsGenerator.py

# Modify original namelist
python3 AdaptNamelists.py

# Copy the namelists in the remote folder
cp ${NEW_NAMELIST}/* ${NAMELIST_FLD}
cp namelist_precisions ${NAMELIST_FLD}

# Move database
mv vault.pkl ${DATABASE_FLD}

#coping files to remote
echo "Copying files to "${HPC_MACHINE}" machine ..."
scp -r ${RUNDIR//Local}/Remote ${HPC_USER}@${HPC_MACHINE}:${REMOTE_DIR}  2> /dev/null

echo "All files has been copied to "${HPC_USER}@${HPC_MACHINE}:${REMOTE_DIR}
